prefetch_write

Function prefetch_write 

pub fn prefetch_write<T>(ptr: *const T)
Prefetch memory for writing.

This function hints to the processor that the specified memory location will be written soon. On most architectures, this is equivalent to prefetch_read since writing also requires reading the cache line.