pub fn has_native_vector_path<T: SimdScalar>() -> boolExpand description
Returns whether T has a native vector backend on the current CPU.
pub fn has_native_vector_path<T: SimdScalar>() -> boolReturns whether T has a native vector backend on the current CPU.