pub fn prefetch_range_read<T>(ptr: *const T, bytes: usize)Expand description
Prefetch a range of memory for reading.
This function prefetches multiple cache lines starting from the given pointer for the specified number of bytes.
Arguments
ptr- Starting memory addressbytes- Number of bytes to prefetch