pub fn prefetch_write<T>(ptr: *const T)Expand description
Prefetch memory for writing.
This function hints to the processor that the specified memory location will be written soon. On most architectures, this is equivalent to prefetch_read since writing also requires reading the cache line.